==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Umowa.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Umowa extends GenericDPSObject {
    /**
     * UMOWA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * UMOWA.EWIDENCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaId;

    /**
     * UMOWA.ZLECENIODAWCA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zleceniodawcaId;

    /**
     * UMOWA.DATA_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataDo;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return UMOWA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * UMOWA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return UMOWA.EWIDENCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaId() {
        return ewidencjaId;
    }

    /**
     * UMOWA.EWIDENCJA_ID
     *
     * @param ewidencjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaId(Long ewidencjaId) {
        this.ewidencjaId = ewidencjaId;
    }

    /**
     * @return UMOWA.ZLECENIODAWCA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZleceniodawcaId() {
        return zleceniodawcaId;
    }

    /**
     * UMOWA.ZLECENIODAWCA_ID
     *
     * @param zleceniodawcaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZleceniodawcaId(Long zleceniodawcaId) {
        this.zleceniodawcaId = zleceniodawcaId;
    }

    /**
     * @return UMOWA.DATA_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * UMOWA.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Umowa other = (Umowa) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaId() == null ? other.getEwidencjaId() == null : this.getEwidencjaId().equals(other.getEwidencjaId()))
            && (this.getZleceniodawcaId() == null ? other.getZleceniodawcaId() == null : this.getZleceniodawcaId().equals(other.getZleceniodawcaId()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaId() == null) ? 0 : getEwidencjaId().hashCode());
        result = prime * result + ((getZleceniodawcaId() == null) ? 0 : getZleceniodawcaId().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaId=").append(ewidencjaId);
        sb.append(", zleceniodawcaId=").append(zleceniodawcaId);
        sb.append(", dataDo=").append(dataDo);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Umowa.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Umowa extends GenericDPSObject {
    /**
     * UMOWA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * UMOWA.EWIDENCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaId;

    /**
     * UMOWA.ZLECENIODAWCA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zleceniodawcaId;

    /**
     * UMOWA.DATA_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataDo;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return UMOWA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * UMOWA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return UMOWA.EWIDENCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaId() {
        return ewidencjaId;
    }

    /**
     * UMOWA.EWIDENCJA_ID
     *
     * @param ewidencjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaId(Long ewidencjaId) {
        this.ewidencjaId = ewidencjaId;
    }

    /**
     * @return UMOWA.ZLECENIODAWCA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZleceniodawcaId() {
        return zleceniodawcaId;
    }

    /**
     * UMOWA.ZLECENIODAWCA_ID
     *
     * @param zleceniodawcaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZleceniodawcaId(Long zleceniodawcaId) {
        this.zleceniodawcaId = zleceniodawcaId;
    }

    /**
     * @return UMOWA.DATA_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * UMOWA.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Umowa other = (Umowa) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaId() == null ? other.getEwidencjaId() == null : this.getEwidencjaId().equals(other.getEwidencjaId()))
            && (this.getZleceniodawcaId() == null ? other.getZleceniodawcaId() == null : this.getZleceniodawcaId().equals(other.getZleceniodawcaId()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaId() == null) ? 0 : getEwidencjaId().hashCode());
        result = prime * result + ((getZleceniodawcaId() == null) ? 0 : getZleceniodawcaId().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaId=").append(ewidencjaId);
        sb.append(", zleceniodawcaId=").append(zleceniodawcaId);
        sb.append(", dataDo=").append(dataDo);
        sb.append("]");
        return sb.toString();
    }
}
